# :coding: utf-8
# :copyright: Copyright (c) 2024 ftrack
import maya.cmds as cmds

from ftrack_framework_core.plugin import BasePlugin
from ftrack_framework_core.exceptions.plugin import PluginExecutionError


class MayaChrCollectorPlugin(BasePlugin):
    name = 'maya_chr_collector'

    def ui_hook(self, payload):
        '''
        Return the first available object that ends 
        with the given expression from the options in Maya
        '''
        expression = payload['expression']
        pre_defined_chr_object = payload['collected_chr_object']
        if pre_defined_chr_object:
            return pre_defined_chr_object
        all_objects = cmds.ls()
        for obj in all_objects:
            if obj.endswith(str(expression)):
                return obj
        return None

    def run(self, store):
        '''
        Set the scollected_chr_object to the *store*
        '''
        try:
            # Pick the collected_chr_object from the options
            collected_chr_object = self.options['collected_chr_object']
        except Exception as error:
            raise PluginExecutionError(f"Provide collected_chr_object: {error}")

        self.logger.debug(f"Character {collected_chr_object}, has been collected.")
        # pick the component name from the options
        component_name = self.options.get('component', 'main')
        # store the collected_chr_object into the store to be picked by next plugins
        store['components'][component_name]['collected_chr_object'] = collected_chr_object
